@@ -1,5 +1,5 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -7,7 +7,6 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -41,7 +40,6 @@ public class IApplianceImportMachines {
 
     @XmlElement(required = true)
     protected String _this;
-    @XmlSchemaType(name = "string")
     protected List<ImportOptions> options;
 
     /**
