@@ -1,5 +1,5 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -7,7 +7,6 @@ import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -49,7 +48,6 @@ public class IGuestSessionDirectoryCopy {
     protected String source;
     @XmlElement(required = true)
     protected String destination;
-    @XmlSchemaType(name = "string")
     protected List<DirectoryCopyFlag> flags;
 
     /**
