@@ -1,11 +1,10 @@
 
-package org.virtualbox_6_0.jaxws;
+package org.virtualbox_6_1.jaxws;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
-import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlType;
 
 
@@ -44,7 +43,6 @@ public class IMachineAddUSBController {
     @XmlElement(required = true)
     protected String name;
     @XmlElement(required = true)
-    @XmlSchemaType(name = "string")
     protected USBControllerType type;
 
     /**
